Introduction
============


.. image:: https://readthedocs.org/projects/circuitpython-candlesticks/badge/?version=latest
    :target: https://circuitpython-candlesticks.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status


.. image:: https://img.shields.io/discord/327254708534116352.svg
    :target: https://adafru.it/discord
    :alt: Discord


.. image:: https://github.com/jposada202020/CircuitPython_Candlesticks/workflows/Build%20CI/badge.svg
    :target: https://github.com/jposada202020/CircuitPython_Candlesticks/actions
    :alt: Build Status


.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Code Style: Black

Graphical representation of the stock movement in candlestick form

.. image:: https://user-images.githubusercontent.com/34255413/113015855-ef66d280-914b-11eb-9bc4-6b524bcfdef2.png


Dependencies
=============
This driver depends on:

* `Adafruit CircuitPython <https://github.com/adafruit/circuitpython>`_

Please ensure all dependencies are available on the CircuitPython filesystem.
This is easily achieved by downloading
`the Adafruit library and driver bundle <https://circuitpython.org/libraries>`_
or individual libraries can be installed using
`circup <https://github.com/adafruit/circup>`_.

Usage Example
=============

See scripts in the examples directory of this repository.

Contributing
============

Contributions are welcome! Please read our `Code of Conduct
<https://github.com/jposada202020/CircuitPython_Candlesticks/blob/master/CODE_OF_CONDUCT.md>`_
before contributing to help this project stay welcoming.

Documentation
=============

For information on building library documentation, please check out
`this guide <https://learn.adafruit.com/creating-and-sharing-a-circuitpython-library/sharing-our-docs-on-readthedocs#sphinx-5-1>`_.
